==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d1/d2b/structResolverObject.js <==
var structResolverObject =
[
    [ "ResolverObject", "d1/d2b/structResolverObject.html#af6ac08b47bdedaa347eacf517ea5b0f3", null ],
    [ "~ResolverObject", "d1/d2b/structResolverObject.html#a84bc40741289e3e275b222deb81b7db9", null ],
    [ "GetRemainingTriggers", "d1/d2b/structResolverObject.html#a970fb7d0619ded1ad3d06cd9bc8dc04e", null ],
    [ "GetReseedSum", "d1/d2b/structResolverObject.html#a6e72747d5ead98866e9e0df60f367ffb", null ],
    [ "GetScope", "d1/d2b/structResolverObject.html#a2cf261571ac1449c3fde6d0ab2a2db39", null ],
    [ "ResetState", "d1/d2b/structResolverObject.html#aa54ecf9ccedc4a7eb56ec958b2ab4eb9", null ],
    [ "Resolve", "d1/d2b/structResolverObject.html#adbb62ab707a1e92497f05a6a3e0cdb21", null ],
    [ "ResolveCallback", "d1/d2b/structResolverObject.html#a4a1daca51619d04e6e89688dbd330535", null ],
    [ "ResolveReal", "d1/d2b/structResolverObject.html#a7a3042fc9e9d61f6dab41bbc2dc4c5e7", null ],
    [ "callback", "d1/d2b/structResolverObject.html#ab7ba1bb67ece20d52d32f373f5661160", null ],
    [ "callback_param1", "d1/d2b/structResolverObject.html#a1049f11327b6f6d9d9e5fb4a227bef0d", null ],
    [ "callback_param2", "d1/d2b/structResolverObject.html#afbeccc383afba1c80d580179c2d06529", null ],
    [ "default_scope", "d1/d2b/structResolverObject.html#ab2d32a111bd62b26d20e724d76190eaf", null ],
    [ "grffile", "d1/d2b/structResolverObject.html#a23084dbf87fc3ebe858b7b4f81b3892c", null ],
    [ "last_value", "d1/d2b/structResolverObject.html#a34eae5a88d1807dcd9cac69623afdf42", null ],
    [ "reseed", "d1/d2b/structResolverObject.html#a1a8049ffc59b27434e956e7580ee006c", null ],
    [ "root_spritegroup", "d1/d2b/structResolverObject.html#adcf0e2fd028e6dde551d966d1a46523b", null ],
    [ "used_triggers", "d1/d2b/structResolverObject.html#acef413e05847ae7bf3c80c70affad444", null ],
    [ "waiting_triggers", "d1/d2b/structResolverObject.html#a8acd9535718984783cb53409f6808ae8", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d1/d2b/structResolverObject.js <==
var structResolverObject =
[
    [ "ResolverObject", "d1/d2b/structResolverObject.html#af6ac08b47bdedaa347eacf517ea5b0f3", null ],
    [ "~ResolverObject", "d1/d2b/structResolverObject.html#a84bc40741289e3e275b222deb81b7db9", null ],
    [ "GetDebugID", "d1/d2b/structResolverObject.html#a716530385924b9be6cfff5529ffbe687", null ],
    [ "GetFeature", "d1/d2b/structResolverObject.html#ad10be7d94c2b7038a5a725e4ec493b4c", null ],
    [ "GetRemainingTriggers", "d1/d2b/structResolverObject.html#a970fb7d0619ded1ad3d06cd9bc8dc04e", null ],
    [ "GetReseedSum", "d1/d2b/structResolverObject.html#a6e72747d5ead98866e9e0df60f367ffb", null ],
    [ "GetScope", "d1/d2b/structResolverObject.html#a2cf261571ac1449c3fde6d0ab2a2db39", null ],
    [ "ResetState", "d1/d2b/structResolverObject.html#aa54ecf9ccedc4a7eb56ec958b2ab4eb9", null ],
    [ "Resolve", "d1/d2b/structResolverObject.html#adbb62ab707a1e92497f05a6a3e0cdb21", null ],
    [ "ResolveCallback", "d1/d2b/structResolverObject.html#a4a1daca51619d04e6e89688dbd330535", null ],
    [ "ResolveReal", "d1/d2b/structResolverObject.html#a7a3042fc9e9d61f6dab41bbc2dc4c5e7", null ],
    [ "callback", "d1/d2b/structResolverObject.html#ab7ba1bb67ece20d52d32f373f5661160", null ],
    [ "callback_param1", "d1/d2b/structResolverObject.html#a1049f11327b6f6d9d9e5fb4a227bef0d", null ],
    [ "callback_param2", "d1/d2b/structResolverObject.html#afbeccc383afba1c80d580179c2d06529", null ],
    [ "default_scope", "d1/d2b/structResolverObject.html#ab2d32a111bd62b26d20e724d76190eaf", null ],
    [ "grffile", "d1/d2b/structResolverObject.html#a23084dbf87fc3ebe858b7b4f81b3892c", null ],
    [ "last_value", "d1/d2b/structResolverObject.html#a34eae5a88d1807dcd9cac69623afdf42", null ],
    [ "reseed", "d1/d2b/structResolverObject.html#a1a8049ffc59b27434e956e7580ee006c", null ],
    [ "root_spritegroup", "d1/d2b/structResolverObject.html#adcf0e2fd028e6dde551d966d1a46523b", null ],
    [ "used_triggers", "d1/d2b/structResolverObject.html#acef413e05847ae7bf3c80c70affad444", null ],
    [ "waiting_triggers", "d1/d2b/structResolverObject.html#a8acd9535718984783cb53409f6808ae8", null ]
];
